@@ -31,7 +31,6 @@ import (
 	"time"
 
 	"github.com/kelseyhightower/envconfig"
-	zipkin "github.com/openzipkin/zipkin-go"
 	"github.com/pkg/errors"
 	"go.opencensus.io/plugin/ochttp"
 	"go.opencensus.io/stats"
@@ -39,9 +38,12 @@ import (
 	"go.uber.org/zap"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/wait"
+	pkglogging "knative.dev/pkg/logging"
 	"knative.dev/pkg/logging/logkey"
 	"knative.dev/pkg/metrics"
 	"knative.dev/pkg/signals"
+	"knative.dev/pkg/tracing"
+	tracingconfig "knative.dev/pkg/tracing/config"
 	"knative.dev/serving/pkg/activator"
 	activatorutil "knative.dev/serving/pkg/activator/util"
 	"knative.dev/serving/pkg/apis/networking"
@@ -53,8 +55,6 @@ import (
 	"knative.dev/serving/pkg/queue/health"
 	"knative.dev/serving/pkg/queue/readiness"
 	queuestats "knative.dev/serving/pkg/queue/stats"
-	"knative.dev/serving/pkg/tracing"
-	tracingconfig "knative.dev/serving/pkg/tracing/config"
 )
 
 const (
@@ -79,6 +79,7 @@ const (
 	responseTimeInMsecN    = "request_latencies"
 	appRequestCountN       = "app_request_count"
 	appResponseTimeInMsecN = "app_request_latencies"
+	queueDepthN            = "queue_depth"
 
 	// requestQueueHealthPath specifies the path for health checks for
 	// queue-proxy.
@@ -90,6 +91,8 @@ const (
 	// started as early as possible while still wanting to give the container some breathing
 	// room to get up and running.
 	aggressivePollInterval = 25 * time.Millisecond
+	// reportingPeriod is the interval of time between reporting stats by queue proxy.
+	reportingPeriod = 1 * time.Second
 )
 
 var (
@@ -112,66 +115,57 @@ var (
 		appResponseTimeInMsecN,
 		"The response time in millisecond",
 		stats.UnitMilliseconds)
+	queueDepthM = stats.Int64(
+		queueDepthN,
+		"The current number of items in the serving and waiting queue, or not reported if unlimited concurrency.",
+		stats.UnitDimensionless)
 
 	readinessProbeTimeout = flag.Int("probe-period", -1, "run readiness probe with given timeout")
 )
 
 type config struct {
-	ContainerConcurrency         int     `split_words:"true" required:"true"`
-	QueueServingPort             int     `split_words:"true" required:"true"`
-	RevisionTimeoutSeconds       int     `split_words:"true" required:"true"`
-	UserPort                     int     `split_words:"true" required:"true"`
-	EnableVarLogCollection       bool    `split_words:"true"` // optional
-	ServingConfiguration         string  `split_words:"true" required:"true"`
-	ServingNamespace             string  `split_words:"true" required:"true"`
-	ServingPodIP                 string  `split_words:"true" required:"true"`
-	ServingPod                   string  `split_words:"true" required:"true"`
-	ServingRevision              string  `split_words:"true" required:"true"`
-	ServingService               string  `split_words:"true"` // optional
-	UserContainerName            string  `split_words:"true" required:"true"`
-	VarLogVolumeName             string  `split_words:"true" required:"true"`
-	InternalVolumePath           string  `split_words:"true" required:"true"`
-	ServingLoggingConfig         string  `split_words:"true" required:"true"`
-	ServingLoggingLevel          string  `split_words:"true" required:"true"`
-	ServingRequestMetricsBackend string  `split_words:"true" required:"true"`
-	ServingRequestLogTemplate    string  `split_words:"true" required:"true"`
-	ServingReadinessProbe        string  `split_words:"true" required:"true"`
-	TracingConfigDebug           bool    `split_words:"true"` // optional
-	TracingConfigEnable          bool    `split_words:"true"` // optional
-	TracingConfigSampleRate      float64 `split_words:"true"` // optional
-	TracingConfigZipkinEndpoint  string  `split_words:"true"` // optional
+	ContainerConcurrency   int    `split_words:"true" required:"true"`
+	QueueServingPort       int    `split_words:"true" required:"true"`
+	UserPort               int    `split_words:"true" required:"true"`
+	RevisionTimeoutSeconds int    `split_words:"true" required:"true"`
+	ServingReadinessProbe  string `split_words:"true" required:"true"`
+
+	// Logging configuration
+	ServingLoggingConfig      string `split_words:"true" required:"true"`
+	ServingLoggingLevel       string `split_words:"true" required:"true"`
+	ServingRequestLogTemplate string `split_words:"true"` // optional
+
+	// Metrics configuration
+	ServingNamespace             string `split_words:"true" required:"true"`
+	ServingRevision              string `split_words:"true" required:"true"`
+	ServingConfiguration         string `split_words:"true" required:"true"`
+	ServingPodIP                 string `split_words:"true" required:"true"`
+	ServingPod                   string `split_words:"true" required:"true"`
+	ServingService               string `split_words:"true"` // optional
+	ServingRequestMetricsBackend string `split_words:"true"` // optional
+
+	// /var/log configuration
+	EnableVarLogCollection bool   `split_words:"true"` // optional
+	UserContainerName      string `split_words:"true"` // optional
+	VarLogVolumeName       string `split_words:"true"` // optional
+	InternalVolumePath     string `split_words:"true"` // optional
+
+	// Tracing configuration
+	TracingConfigDebug                bool                      `split_words:"true"` // optional
+	TracingConfigBackend              tracingconfig.BackendType `split_words:"true"` // optional
+	TracingConfigSampleRate           float64                   `split_words:"true"` // optional
+	TracingConfigZipkinEndpoint       string                    `split_words:"true"` // optional
+	TracingConfigStackdriverProjectID string                    `split_words:"true"` // optional
 }
 
 // Make handler a closure for testing.
-func handler(reqChan chan queue.ReqEvent, breaker *queue.Breaker, handler http.Handler, prober func() bool) func(http.ResponseWriter, *http.Request) {
+func handler(reqChan chan queue.ReqEvent, breaker *queue.Breaker, handler http.Handler,
+	prober func() bool) func(http.ResponseWriter, *http.Request) {
 	return func(w http.ResponseWriter, r *http.Request) {
 		ph := network.KnativeProbeHeader(r)
 		switch {
 		case ph != "":
-			_, probeSpan := trace.StartSpan(r.Context(), "probe")
-			if ph != queue.Name {
-				http.Error(w, fmt.Sprintf(badProbeTemplate, ph), http.StatusBadRequest)
-				probeSpan.Annotate([]trace.Attribute{
-					trace.StringAttribute("queueproxy.probe.error", fmt.Sprintf(badProbeTemplate, ph))}, "error")
-				probeSpan.End()
-				return
-			}
-			if prober != nil {
-				if prober() {
-					// Respond with the name of the component handling the request.
-					w.Write([]byte(queue.Name))
-				} else {
-					http.Error(w, "container not ready", http.StatusServiceUnavailable)
-					probeSpan.Annotate([]trace.Attribute{
-						trace.StringAttribute("queueproxy.probe.error", "container not ready")}, "error")
-				}
-
-			} else {
-				http.Error(w, "no probe", http.StatusInternalServerError)
-				probeSpan.Annotate([]trace.Attribute{
-					trace.StringAttribute("queueproxy.probe.error", "no probe")}, "error")
-			}
-			probeSpan.End()
+			handleKnativeProbe(w, r, ph, prober)
 			return
 		case network.IsKubeletProbe(r):
 			probeCtx, probeSpan := trace.StartSpan(r.Context(), "probe")
@@ -195,10 +189,15 @@ func handler(reqChan chan queue.ReqEvent, breaker *queue.Breaker, handler http.H
 
 		// Enforce queuing and concurrency limits.
 		if breaker != nil {
-			if !breaker.Maybe(r.Context(), func() {
+			if err := breaker.Maybe(r.Context(), func() {
 				handler.ServeHTTP(w, r.WithContext(proxyCtx))
-			}) {
-				http.Error(w, "overload", http.StatusServiceUnavailable)
+			}); err != nil {
+				switch err {
+				case context.DeadlineExceeded, queue.ErrRequestQueueFull:
+					http.Error(w, err.Error(), http.StatusServiceUnavailable)
+				default:
+					w.WriteHeader(http.StatusInternalServerError)
+				}
 			}
 		} else {
 			handler.ServeHTTP(w, r.WithContext(proxyCtx))
@@ -206,6 +205,35 @@ func handler(reqChan chan queue.ReqEvent, breaker *queue.Breaker, handler http.H
 	}
 }
 
+func handleKnativeProbe(w http.ResponseWriter, r *http.Request, ph string, prober func() bool) {
+	_, probeSpan := trace.StartSpan(r.Context(), "probe")
+	defer probeSpan.End()
+
+	if ph != queue.Name {
+		http.Error(w, fmt.Sprintf(badProbeTemplate, ph), http.StatusBadRequest)
+		probeSpan.Annotate([]trace.Attribute{
+			trace.StringAttribute("queueproxy.probe.error", fmt.Sprintf(badProbeTemplate, ph))}, "error")
+		return
+	}
+
+	if prober == nil {
+		http.Error(w, "no probe", http.StatusInternalServerError)
+		probeSpan.Annotate([]trace.Attribute{
+			trace.StringAttribute("queueproxy.probe.error", "no probe")}, "error")
+		return
+	}
+
+	if !prober() {
+		http.Error(w, "container not ready", http.StatusServiceUnavailable)
+		probeSpan.Annotate([]trace.Attribute{
+			trace.StringAttribute("queueproxy.probe.error", "container not ready")}, "error")
+		return
+	}
+
+	// Respond with the name of the component handling the request.
+	w.Write([]byte(queue.Name))
+}
+
 func probeQueueHealthPath(port int, timeoutSeconds int) error {
 	url := fmt.Sprintf(healthURLTemplate, port)
 	timeoutDuration := readiness.PollTimeout
@@ -268,7 +296,7 @@ func main() {
 	}
 
 	// Setup the logger.
-	logger, _ = logging.NewLogger(env.ServingLoggingConfig, env.ServingLoggingLevel)
+	logger, _ = pkglogging.NewLogger(env.ServingLoggingConfig, env.ServingLoggingLevel)
 	logger = logger.Named("queueproxy")
 	defer flush(logger)
 
@@ -276,58 +304,12 @@ func main() {
 		zap.String(logkey.Key, types.NamespacedName{Namespace: env.ServingNamespace, Name: env.ServingRevision}.String()),
 		zap.String(logkey.Pod, env.ServingPod))
 
-	// Setup the reverse proxy to forward requests.
-	target := &url.URL{
-		Scheme: "http",
-		Host:   net.JoinHostPort("127.0.0.1", strconv.Itoa(env.UserPort)),
-	}
-
-	httpProxy := httputil.NewSingleHostReverseProxy(target)
-	httpProxy.Transport = network.AutoTransport
-
-	if env.TracingConfigEnable {
-		queueProxyL3 := fmt.Sprintf("%s:%d", env.ServingPod, networking.ServiceHTTPPort)
-		zipkinEndpoint, err := zipkin.NewEndpoint(env.ServingPod, queueProxyL3)
-
-		if err != nil {
-			logger.Fatalw("Unable to create tracing endpoint", zap.Error(err))
-			return
-		}
-
-		oct := tracing.NewOpenCensusTracer(
-			tracing.WithZipkinExporter(tracing.CreateZipkinReporter, zipkinEndpoint),
-		)
-
-		cfg := tracingconfig.Config{
-			Enable:         env.TracingConfigEnable,
-			Debug:          env.TracingConfigDebug,
-			ZipkinEndpoint: env.TracingConfigZipkinEndpoint,
-			SampleRate:     env.TracingConfigSampleRate,
-		}
-		oct.ApplyConfig(&cfg)
-
-		httpProxy.Transport = &ochttp.Transport{
-			Base: network.AutoTransport,
-		}
-	}
-
-	httpProxy.FlushInterval = -1
-	activatorutil.SetupHeaderPruning(httpProxy)
-
-	// Setup the breaker to enforce containreConcurrency.
-	// If env.ContainerConcurrency == 0 then concurrency is unlimited.
-	var breaker *queue.Breaker
-	if env.ContainerConcurrency > 0 {
-		// We set the queue depth to be equal to the container concurrency * 10 to
-		// allow the autoscaler to get a strong enough signal.
-		queueDepth := env.ContainerConcurrency * 10
-		params := queue.BreakerParams{QueueDepth: queueDepth, MaxConcurrency: env.ContainerConcurrency, InitialCapacity: env.ContainerConcurrency}
-		breaker = queue.NewBreaker(params)
-		logger.Infof("Queue container is starting with %#v", params)
+	if err := validateEnv(env); err != nil {
+		logger.Fatal(err.Error())
 	}
 
 	// Setup reporters and processes to handle stat reporting.
-	promStatReporter, err := queue.NewPrometheusStatsReporter(env.ServingNamespace, env.ServingConfiguration, env.ServingRevision, env.ServingPod)
+	promStatReporter, err := queue.NewPrometheusStatsReporter(env.ServingNamespace, env.ServingConfiguration, env.ServingRevision, env.ServingPod, reportingPeriod)
 	if err != nil {
 		logger.Fatalw("Failed to create stats reporter", zap.Error(err))
 	}
@@ -344,70 +326,23 @@ func main() {
 
 	reqChan := make(chan queue.ReqEvent, requestCountingQueueLength)
 	defer close(reqChan)
-	reportTicker := time.NewTicker(queue.ReporterReportingPeriod)
+
+	reportTicker := time.NewTicker(reportingPeriod)
 	defer reportTicker.Stop()
+
 	queue.NewStats(env.ServingPod, queue.Channels{
 		ReqChan:    reqChan,
 		ReportChan: reportTicker.C,
 		StatChan:   statChan,
 	}, time.Now())
 
-	// Setup request metrics reporting for end-user metrics.
-	metricsSupported := false
-	if env.ServingRequestMetricsBackend != "" {
-		if err := setupMetricsExporter(env.ServingRequestMetricsBackend); err == nil {
-			metricsSupported = true
-		} else {
-			logger.Errorw("Error setting up request metrics exporter. Request metrics will be unavailable.", zap.Error(err))
-		}
-	}
-
 	// Setup probe to run for checking user-application healthiness.
-	coreProbe, err := readiness.DecodeProbe(env.ServingReadinessProbe)
-	if err != nil {
-		logger.Fatalw("Queue container failed to parse readiness probe", zap.Error(err))
-	}
-	rp := readiness.NewProbe(coreProbe)
-
-	// Create queue handler chain.
-	// Note: innermost handlers are specified first, ie. the last handler in the chain will be executed first.
-	var composedHandler http.Handler = httpProxy
-	if metricsSupported {
-		composedHandler = pushRequestMetricHandler(httpProxy, appRequestCountM, appResponseTimeInMsecM, env)
-	}
-	composedHandler = http.HandlerFunc(handler(reqChan, breaker, composedHandler, rp.ProbeContainer))
-	composedHandler = queue.ForwardedShimHandler(composedHandler)
-	composedHandler = queue.TimeToFirstByteTimeoutHandler(composedHandler,
-		time.Duration(env.RevisionTimeoutSeconds)*time.Second, "request timeout")
-	composedHandler = pushRequestLogHandler(composedHandler, env)
-
-	if metricsSupported {
-		composedHandler = pushRequestMetricHandler(composedHandler, requestCountM, responseTimeInMsecM, env)
-	}
-	composedHandler = tracing.HTTPSpanMiddleware(composedHandler)
-	server := network.NewServer(":"+strconv.Itoa(env.QueueServingPort), composedHandler)
-
-	adminMux := http.NewServeMux()
+	probe := buildProbe(env.ServingReadinessProbe)
 	healthState := &health.State{}
-	adminMux.HandleFunc(requestQueueHealthPath, healthState.HealthHandler(func() bool {
-		if !rp.ProbeContainer() {
-			return false
-		}
-		logger.Info("User-container successfully probed.")
-		return true
-	}, rp.IsAggressive()))
-	adminMux.HandleFunc(queue.RequestQueueDrainPath, healthState.DrainHandler())
-	adminServer := &http.Server{
-		Addr:    ":" + strconv.Itoa(networking.QueueAdminPort),
-		Handler: adminMux,
-	}
 
-	metricsMux := http.NewServeMux()
-	metricsMux.Handle("/metrics", promStatReporter.Handler())
-	metricsServer := &http.Server{
-		Addr:    ":" + strconv.Itoa(networking.AutoscalingQueueMetricsPort),
-		Handler: metricsMux,
-	}
+	server := buildServer(env, probe, reqChan, logger)
+	adminServer := buildAdminServer(healthState, probe, logger)
+	metricsServer := buildMetricsServer(promStatReporter)
 
 	servers := map[string]*http.Server{
 		"main":    server,
@@ -428,12 +363,6 @@ func main() {
 	// Setup /var/log.
 	// Logic that isn't required to be executed before the critical path
 	// and should be started last to not impact start up latency
-	if env.VarLogVolumeName == "" && env.EnableVarLogCollection {
-		logger.Fatal("VAR_LOG_VOLUME_NAME must be specified when ENABLE_VAR_LOG_COLLECTION is true")
-	}
-	if env.InternalVolumePath == "" && env.EnableVarLogCollection {
-		logger.Fatal("INTERNAL_VOLUME_PATH must be specified when ENABLE_VAR_LOG_COLLECTION is true")
-	}
 	go func() {
 		if env.EnableVarLogCollection {
 			createVarLogLink(env)
@@ -468,6 +397,141 @@ func main() {
 	}
 }
 
+func validateEnv(env config) error {
+	if !env.EnableVarLogCollection {
+		return nil
+	}
+
+	if env.VarLogVolumeName == "" {
+		return errors.New("VAR_LOG_VOLUME_NAME must be specified when ENABLE_VAR_LOG_COLLECTION is true")
+	}
+	if env.InternalVolumePath == "" {
+		return errors.New("INTERNAL_VOLUME_PATH must be specified when ENABLE_VAR_LOG_COLLECTION is true")
+	}
+
+	return nil
+}
+
+func buildProbe(probeJSON string) *readiness.Probe {
+	coreProbe, err := readiness.DecodeProbe(probeJSON)
+	if err != nil {
+		logger.Fatalw("Queue container failed to parse readiness probe", zap.Error(err))
+	}
+	return readiness.NewProbe(coreProbe)
+}
+
+func buildServer(env config, rp *readiness.Probe, reqChan chan queue.ReqEvent, logger *zap.SugaredLogger) *http.Server {
+	target := &url.URL{
+		Scheme: "http",
+		Host:   net.JoinHostPort("127.0.0.1", strconv.Itoa(env.UserPort)),
+	}
+
+	httpProxy := httputil.NewSingleHostReverseProxy(target)
+	httpProxy.Transport = buildTransport(env, logger)
+	httpProxy.ErrorHandler = network.ErrorHandler(logger)
+
+	httpProxy.FlushInterval = -1
+	activatorutil.SetupHeaderPruning(httpProxy)
+
+	breaker := buildBreaker(env)
+	metricsSupported := supportsMetrics(env, logger)
+
+	// Create queue handler chain.
+	// Note: innermost handlers are specified first, ie. the last handler in the chain will be executed first.
+	var composedHandler http.Handler = httpProxy
+	if metricsSupported {
+		composedHandler = pushRequestMetricHandler(httpProxy, appRequestCountM, appResponseTimeInMsecM,
+			queueDepthM, breaker, env)
+	}
+	composedHandler = http.HandlerFunc(handler(reqChan, breaker, composedHandler, rp.ProbeContainer))
+	composedHandler = queue.ForwardedShimHandler(composedHandler)
+	composedHandler = queue.TimeToFirstByteTimeoutHandler(composedHandler,
+		time.Duration(env.RevisionTimeoutSeconds)*time.Second, "request timeout")
+	composedHandler = pushRequestLogHandler(composedHandler, env)
+
+	if metricsSupported {
+		composedHandler = pushRequestMetricHandler(composedHandler, requestCountM, responseTimeInMsecM,
+			nil /*queueDepthM*/, nil /*breaker*/, env)
+	}
+	composedHandler = tracing.HTTPSpanMiddleware(composedHandler)
+	composedHandler = network.NewProbeHandler(composedHandler)
+
+	return network.NewServer(":"+strconv.Itoa(env.QueueServingPort), composedHandler)
+}
+
+func buildTransport(env config, logger *zap.SugaredLogger) http.RoundTripper {
+	if env.TracingConfigBackend == tracingconfig.None {
+		return network.AutoTransport
+	}
+
+	oct := tracing.NewOpenCensusTracer(tracing.WithExporter(env.ServingPod, logger))
+	oct.ApplyConfig(&tracingconfig.Config{
+		Backend:              env.TracingConfigBackend,
+		Debug:                env.TracingConfigDebug,
+		ZipkinEndpoint:       env.TracingConfigZipkinEndpoint,
+		StackdriverProjectID: env.TracingConfigStackdriverProjectID,
+		SampleRate:           env.TracingConfigSampleRate,
+	})
+
+	return &ochttp.Transport{
+		Base: network.AutoTransport,
+	}
+}
+
+func buildBreaker(env config) *queue.Breaker {
+	if env.ContainerConcurrency < 1 {
+		return nil
+	}
+
+	// We set the queue depth to be equal to the container concurrency * 10 to
+	// allow the autoscaler time to react.
+	queueDepth := env.ContainerConcurrency * 10
+	params := queue.BreakerParams{QueueDepth: queueDepth, MaxConcurrency: env.ContainerConcurrency, InitialCapacity: env.ContainerConcurrency}
+	logger.Infof("Queue container is starting with %#v", params)
+
+	return queue.NewBreaker(params)
+}
+
+func supportsMetrics(env config, logger *zap.SugaredLogger) bool {
+	// Setup request metrics reporting for end-user metrics.
+	if env.ServingRequestMetricsBackend == "" {
+		return false
+	}
+
+	if err := setupMetricsExporter(env.ServingRequestMetricsBackend); err != nil {
+		logger.Errorw("Error setting up request metrics exporter. Request metrics will be unavailable.", zap.Error(err))
+		return false
+	}
+
+	return true
+}
+
+func buildAdminServer(healthState *health.State, probe *readiness.Probe, logger *zap.SugaredLogger) *http.Server {
+	adminMux := http.NewServeMux()
+	adminMux.HandleFunc(requestQueueHealthPath, healthState.HealthHandler(func() bool {
+		if !probe.ProbeContainer() {
+			return false
+		}
+		logger.Info("User-container successfully probed.")
+		return true
+	}, probe.IsAggressive()))
+	adminMux.HandleFunc(queue.RequestQueueDrainPath, healthState.DrainHandler())
+
+	return &http.Server{
+		Addr:    ":" + strconv.Itoa(networking.QueueAdminPort),
+		Handler: adminMux,
+	}
+}
+
+func buildMetricsServer(promStatReporter *queue.PrometheusStatsReporter) *http.Server {
+	metricsMux := http.NewServeMux()
+	metricsMux.Handle("/metrics", promStatReporter.Handler())
+	return &http.Server{
+		Addr:    ":" + strconv.Itoa(networking.AutoscalingQueueMetricsPort),
+		Handler: metricsMux,
+	}
+}
+
 // createVarLogLink creates a symlink allowing the fluentd daemon set to capture the
 // logs from the user container /var/log. See fluentd config for more details.
 func createVarLogLink(env config) {
@@ -502,14 +566,15 @@ func pushRequestLogHandler(currentHandler http.Handler, env config) http.Handler
 	return handler
 }
 
-func pushRequestMetricHandler(currentHandler http.Handler, countMetric *stats.Int64Measure, latencyMetric *stats.Float64Measure, env config) http.Handler {
-	r, err := queuestats.NewStatsReporter(env.ServingNamespace, env.ServingService, env.ServingConfiguration, env.ServingRevision, countMetric, latencyMetric)
+func pushRequestMetricHandler(currentHandler http.Handler, countMetric *stats.Int64Measure,
+	latencyMetric *stats.Float64Measure, queueDepthMetric *stats.Int64Measure, breaker *queue.Breaker, env config) http.Handler {
+	r, err := queuestats.NewStatsReporter(env.ServingNamespace, env.ServingService, env.ServingConfiguration, env.ServingRevision, countMetric, latencyMetric, queueDepthMetric)
 	if err != nil {
 		logger.Errorw("Error setting up request metrics reporter. Request metrics will be unavailable.", zap.Error(err))
 		return currentHandler
 	}
 
-	handler, err := queue.NewRequestMetricHandler(currentHandler, r)
+	handler, err := queue.NewRequestMetricHandler(currentHandler, r, breaker)
 	if err != nil {
 		logger.Errorw("Error setting up request metrics handler. Request metrics will be unavailable.", zap.Error(err))
 		return currentHandler
