@@ -610,7 +610,10 @@ func TestContainerValidation(t *testing.T) {
 				},
 			},
 		},
-		want: apis.ErrDisallowedFields("readinessProbe.failureThreshold"),
+		want: &apis.FieldError{
+			Message: "failureThreshold is disallowed when periodSeconds is zero",
+			Paths:   []string{"readinessProbe.failureThreshold"},
+		},
 	}, {
 		name: "invalid readiness probe (has timeoutSeconds while using special probe)",
 		c: corev1.Container{
@@ -626,7 +629,10 @@ func TestContainerValidation(t *testing.T) {
 				},
 			},
 		},
-		want: apis.ErrDisallowedFields("readinessProbe.timeoutSeconds"),
+		want: &apis.FieldError{
+			Message: "timeoutSeconds is disallowed when periodSeconds is zero",
+			Paths:   []string{"readinessProbe.timeoutSeconds"},
+		},
 	}, {
 		name: "out of bounds probe values",
 		c: corev1.Container{
@@ -984,6 +990,59 @@ func TestVolumeValidation(t *testing.T) {
 			},
 		},
 		want: apis.ErrInvalidValue("@@@", "name"),
+	}, {
+		name: "secret missing keyToPath values",
+		v: corev1.Volume{
+			Name: "foo",
+			VolumeSource: corev1.VolumeSource{
+				Secret: &corev1.SecretVolumeSource{
+					SecretName: "foo",
+					Items:      []corev1.KeyToPath{{}},
+				},
+			},
+		},
+		want: apis.ErrMissingField("items[0].key").Also(apis.ErrMissingField("items[0].path")),
+	}, {
+		name: "configMap missing keyToPath values",
+		v: corev1.Volume{
+			Name: "foo",
+			VolumeSource: corev1.VolumeSource{
+				ConfigMap: &corev1.ConfigMapVolumeSource{
+					LocalObjectReference: corev1.LocalObjectReference{
+						Name: "foo",
+					},
+					Items: []corev1.KeyToPath{{}},
+				},
+			},
+		},
+		want: apis.ErrMissingField("items[0].key").Also(apis.ErrMissingField("items[0].path")),
+	}, {
+		name: "projection missing keyToPath values",
+		v: corev1.Volume{
+			Name: "foo",
+			VolumeSource: corev1.VolumeSource{
+				Projected: &corev1.ProjectedVolumeSource{
+					Sources: []corev1.VolumeProjection{{
+						Secret: &corev1.SecretProjection{
+							LocalObjectReference: corev1.LocalObjectReference{
+								Name: "foo",
+							},
+							Items: []corev1.KeyToPath{{}},
+						}}, {
+						ConfigMap: &corev1.ConfigMapProjection{
+							LocalObjectReference: corev1.LocalObjectReference{
+								Name: "foo",
+							},
+							Items: []corev1.KeyToPath{{}},
+						}},
+					},
+				},
+			},
+		},
+		want: apis.ErrMissingField("projected[0].secret.items[0].key").Also(
+			apis.ErrMissingField("projected[0].secret.items[0].path")).Also(
+			apis.ErrMissingField("projected[1].configMap.items[0].key")).Also(
+			apis.ErrMissingField("projected[1].configMap.items[0].path")),
 	}}
 
 	for _, test := range tests {
