@@ -34,7 +34,7 @@ import (
 	net "knative.dev/serving/pkg/apis/networking"
 	"knative.dev/serving/pkg/apis/serving"
 
-	"knative.dev/serving/pkg/apis/serving/v1beta1"
+	v1 "knative.dev/serving/pkg/apis/serving/v1"
 )
 
 func TestConcurrencyModelValidation(t *testing.T) {
@@ -105,7 +105,7 @@ func TestRevisionSpecValidation(t *testing.T) {
 	}, {
 		name: "missing container",
 		rs: &RevisionSpec{
-			RevisionSpec: v1beta1.RevisionSpec{
+			RevisionSpec: v1.RevisionSpec{
 				PodSpec: corev1.PodSpec{
 					Volumes: []corev1.Volume{{
 						Name: "the-name",
@@ -119,6 +119,34 @@ func TestRevisionSpecValidation(t *testing.T) {
 			},
 		},
 		want: apis.ErrMissingOneOf("container", "containers"),
+	}, {
+		name: "more container",
+		rs: &RevisionSpec{
+			RevisionSpec: v1.RevisionSpec{
+				PodSpec: corev1.PodSpec{
+					Containers: []corev1.Container{{
+						Image: "helloworld",
+					}},
+				},
+			},
+			DeprecatedContainer: &corev1.Container{
+				Name: "deprecatedContainer",
+			},
+		},
+		want: apis.ErrMultipleOneOf("container", "containers"),
+	}, {
+		name: "with ContainerConcurrency",
+		rs: &RevisionSpec{
+			RevisionSpec: v1.RevisionSpec{
+				PodSpec: corev1.PodSpec{
+					Containers: []corev1.Container{{
+						Image: "helloworld",
+					}},
+				},
+				ContainerConcurrency: ptr.Int64(10),
+			},
+		},
+		want: nil,
 	}, {
 		name: "with volume (ok)",
 		rs: &RevisionSpec{
@@ -130,7 +158,7 @@ func TestRevisionSpecValidation(t *testing.T) {
 					ReadOnly:  true,
 				}},
 			},
-			RevisionSpec: v1beta1.RevisionSpec{
+			RevisionSpec: v1.RevisionSpec{
 				PodSpec: corev1.PodSpec{
 					Volumes: []corev1.Volume{{
 						Name: "the-name",
@@ -155,7 +183,7 @@ func TestRevisionSpecValidation(t *testing.T) {
 					ReadOnly:  true,
 				}},
 			},
-			RevisionSpec: v1beta1.RevisionSpec{
+			RevisionSpec: v1.RevisionSpec{
 				PodSpec: corev1.PodSpec{
 					Volumes: []corev1.Volume{{
 						Name: "the-name",
@@ -211,7 +239,7 @@ func TestRevisionSpecValidation(t *testing.T) {
 			DeprecatedContainer: &corev1.Container{
 				Image: "helloworld",
 			},
-			RevisionSpec: v1beta1.RevisionSpec{
+			RevisionSpec: v1.RevisionSpec{
 				TimeoutSeconds: ptr.Int64(6000),
 			},
 		},
@@ -224,7 +252,7 @@ func TestRevisionSpecValidation(t *testing.T) {
 			DeprecatedContainer: &corev1.Container{
 				Image: "helloworld",
 			},
-			RevisionSpec: v1beta1.RevisionSpec{
+			RevisionSpec: v1.RevisionSpec{
 				TimeoutSeconds: ptr.Int64(100),
 			},
 		},
@@ -247,7 +275,7 @@ func TestRevisionSpecValidation(t *testing.T) {
 			DeprecatedContainer: &corev1.Container{
 				Image: "helloworld",
 			},
-			RevisionSpec: v1beta1.RevisionSpec{
+			RevisionSpec: v1.RevisionSpec{
 				TimeoutSeconds: ptr.Int64(0),
 			},
 		},
@@ -258,7 +286,7 @@ func TestRevisionSpecValidation(t *testing.T) {
 			DeprecatedContainer: &corev1.Container{
 				Image: "helloworld",
 			},
-			RevisionSpec: v1beta1.RevisionSpec{
+			RevisionSpec: v1.RevisionSpec{
 				TimeoutSeconds: ptr.Int64(-30),
 			},
 		},
@@ -529,7 +557,7 @@ func TestImmutableFields(t *testing.T) {
 				DeprecatedContainer: &corev1.Container{
 					Image: "helloworld",
 				},
-				RevisionSpec: v1beta1.RevisionSpec{
+				RevisionSpec: v1.RevisionSpec{
 					TimeoutSeconds: ptr.Int64(100),
 				},
 			},
@@ -542,7 +570,7 @@ func TestImmutableFields(t *testing.T) {
 				DeprecatedContainer: &corev1.Container{
 					Image: "helloworld",
 				},
-				RevisionSpec: v1beta1.RevisionSpec{
+				RevisionSpec: v1.RevisionSpec{
 					TimeoutSeconds: ptr.Int64(100),
 				},
 			},
@@ -672,8 +700,10 @@ func TestImmutableFields(t *testing.T) {
 				DeprecatedContainer: &corev1.Container{
 					Image: "helloworld",
 				},
-				RevisionSpec: v1beta1.RevisionSpec{
-					ContainerConcurrency: 100,
+				RevisionSpec: v1.RevisionSpec{
+					PodSpec: corev1.PodSpec{
+						ServiceAccountName: "foobar",
+					},
 				},
 			},
 		},
@@ -690,9 +720,9 @@ func TestImmutableFields(t *testing.T) {
 		want: &apis.FieldError{
 			Message: "Immutable fields changed (-old +new)",
 			Paths:   []string{"spec"},
-			Details: `{v1alpha1.RevisionSpec}.RevisionSpec.ContainerConcurrency:
-	-: "0"
-	+: "100"
+			Details: `{v1alpha1.RevisionSpec}.RevisionSpec.PodSpec.ServiceAccountName:
+	-: ""
+	+: "foobar"
 `,
 		},
 	}, {
@@ -705,8 +735,10 @@ func TestImmutableFields(t *testing.T) {
 				DeprecatedContainer: &corev1.Container{
 					Image: "helloworld",
 				},
-				RevisionSpec: v1beta1.RevisionSpec{
-					ContainerConcurrency: 100,
+				RevisionSpec: v1.RevisionSpec{
+					PodSpec: corev1.PodSpec{
+						ServiceAccountName: "foobar",
+					},
 				},
 			},
 		},
@@ -718,17 +750,14 @@ func TestImmutableFields(t *testing.T) {
 				DeprecatedContainer: &corev1.Container{
 					Image: "busybox",
 				},
-				RevisionSpec: v1beta1.RevisionSpec{
-					ContainerConcurrency: 1,
-				},
 			},
 		},
 		want: &apis.FieldError{
 			Message: "Immutable fields changed (-old +new)",
 			Paths:   []string{"spec"},
-			Details: `{v1alpha1.RevisionSpec}.RevisionSpec.ContainerConcurrency:
-	-: "1"
-	+: "100"
+			Details: `{v1alpha1.RevisionSpec}.RevisionSpec.PodSpec.ServiceAccountName:
+	-: ""
+	+: "foobar"
 {v1alpha1.RevisionSpec}.DeprecatedContainer.Image:
 	-: "busybox"
 	+: "helloworld"
