@@ -28,7 +28,7 @@ import (
 	"knative.dev/pkg/apis"
 	"knative.dev/serving/pkg/apis/config"
 	"knative.dev/serving/pkg/apis/serving"
-	"knative.dev/serving/pkg/apis/serving/v1beta1"
+	v1 "knative.dev/serving/pkg/apis/serving/v1"
 )
 
 func TestServiceDefaulting(t *testing.T) {
@@ -45,9 +45,9 @@ func TestServiceDefaulting(t *testing.T) {
 			Spec: ServiceSpec{
 				RouteSpec: RouteSpec{
 					Traffic: []TrafficTarget{{
-						TrafficTarget: v1beta1.TrafficTarget{
+						TrafficTarget: v1.TrafficTarget{
 							LatestRevision: ptr.Bool(true),
-							Percent:        100,
+							Percent:        ptr.Int64(100),
 						},
 					}},
 				},
@@ -87,8 +87,9 @@ func TestServiceDefaulting(t *testing.T) {
 					Configuration: ConfigurationSpec{
 						DeprecatedRevisionTemplate: &RevisionTemplateSpec{
 							Spec: RevisionSpec{
-								RevisionSpec: v1beta1.RevisionSpec{
-									TimeoutSeconds: ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+								RevisionSpec: v1.RevisionSpec{
+									TimeoutSeconds:       ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+									ContainerConcurrency: ptr.Int64(config.DefaultContainerConcurrency),
 								},
 								DeprecatedContainer: &corev1.Container{
 									Name:           config.DefaultUserContainerName,
@@ -103,7 +104,7 @@ func TestServiceDefaulting(t *testing.T) {
 		},
 	}, {
 		name: "run latest (lemonade)",
-		wc:   v1beta1.WithUpgradeViaDefaulting,
+		wc:   v1.WithUpgradeViaDefaulting,
 		in: &Service{
 			Spec: ServiceSpec{
 				DeprecatedRunLatest: &RunLatestType{
@@ -124,8 +125,9 @@ func TestServiceDefaulting(t *testing.T) {
 				ConfigurationSpec: ConfigurationSpec{
 					Template: &RevisionTemplateSpec{
 						Spec: RevisionSpec{
-							RevisionSpec: v1beta1.RevisionSpec{
-								TimeoutSeconds: ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+							RevisionSpec: v1.RevisionSpec{
+								TimeoutSeconds:       ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+								ContainerConcurrency: ptr.Int64(config.DefaultContainerConcurrency),
 								PodSpec: corev1.PodSpec{
 									Containers: []corev1.Container{{
 										Name:           config.DefaultUserContainerName,
@@ -140,9 +142,9 @@ func TestServiceDefaulting(t *testing.T) {
 				},
 				RouteSpec: RouteSpec{
 					Traffic: []TrafficTarget{{
-						TrafficTarget: v1beta1.TrafficTarget{
+						TrafficTarget: v1.TrafficTarget{
 							LatestRevision: ptr.Bool(true),
-							Percent:        100,
+							Percent:        ptr.Int64(100),
 						},
 					}},
 				},
@@ -157,8 +159,8 @@ func TestServiceDefaulting(t *testing.T) {
 						DeprecatedRevisionTemplate: &RevisionTemplateSpec{
 							Spec: RevisionSpec{
 								DeprecatedContainer: &corev1.Container{},
-								RevisionSpec: v1beta1.RevisionSpec{
-									ContainerConcurrency: 1,
+								RevisionSpec: v1.RevisionSpec{
+									ContainerConcurrency: ptr.Int64(1),
 									TimeoutSeconds:       ptr.Int64(config.DefaultRevisionTimeoutSeconds),
 								},
 							},
@@ -173,8 +175,8 @@ func TestServiceDefaulting(t *testing.T) {
 					Configuration: ConfigurationSpec{
 						DeprecatedRevisionTemplate: &RevisionTemplateSpec{
 							Spec: RevisionSpec{
-								RevisionSpec: v1beta1.RevisionSpec{
-									ContainerConcurrency: 1,
+								RevisionSpec: v1.RevisionSpec{
+									ContainerConcurrency: ptr.Int64(1),
 									TimeoutSeconds:       ptr.Int64(config.DefaultRevisionTimeoutSeconds),
 								},
 								DeprecatedContainer: &corev1.Container{
@@ -209,8 +211,9 @@ func TestServiceDefaulting(t *testing.T) {
 					Configuration: ConfigurationSpec{
 						DeprecatedRevisionTemplate: &RevisionTemplateSpec{
 							Spec: RevisionSpec{
-								RevisionSpec: v1beta1.RevisionSpec{
-									TimeoutSeconds: ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+								RevisionSpec: v1.RevisionSpec{
+									TimeoutSeconds:       ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+									ContainerConcurrency: ptr.Int64(config.DefaultContainerConcurrency),
 								},
 								DeprecatedContainer: &corev1.Container{
 									Name:           config.DefaultUserContainerName,
@@ -225,7 +228,7 @@ func TestServiceDefaulting(t *testing.T) {
 		},
 	}, {
 		name: "pinned (lemonade)",
-		wc:   v1beta1.WithUpgradeViaDefaulting,
+		wc:   v1.WithUpgradeViaDefaulting,
 		in: &Service{
 			Spec: ServiceSpec{
 				DeprecatedPinned: &PinnedType{
@@ -247,8 +250,9 @@ func TestServiceDefaulting(t *testing.T) {
 				ConfigurationSpec: ConfigurationSpec{
 					Template: &RevisionTemplateSpec{
 						Spec: RevisionSpec{
-							RevisionSpec: v1beta1.RevisionSpec{
-								TimeoutSeconds: ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+							RevisionSpec: v1.RevisionSpec{
+								TimeoutSeconds:       ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+								ContainerConcurrency: ptr.Int64(config.DefaultContainerConcurrency),
 								PodSpec: corev1.PodSpec{
 									Containers: []corev1.Container{{
 										Name:           config.DefaultUserContainerName,
@@ -263,9 +267,9 @@ func TestServiceDefaulting(t *testing.T) {
 				},
 				RouteSpec: RouteSpec{
 					Traffic: []TrafficTarget{{
-						TrafficTarget: v1beta1.TrafficTarget{
+						TrafficTarget: v1.TrafficTarget{
 							RevisionName:   "asdf",
-							Percent:        100,
+							Percent:        ptr.Int64(100),
 							LatestRevision: ptr.Bool(false),
 						},
 					}},
@@ -281,8 +285,8 @@ func TestServiceDefaulting(t *testing.T) {
 						DeprecatedRevisionTemplate: &RevisionTemplateSpec{
 							Spec: RevisionSpec{
 								DeprecatedContainer: &corev1.Container{},
-								RevisionSpec: v1beta1.RevisionSpec{
-									ContainerConcurrency: 1,
+								RevisionSpec: v1.RevisionSpec{
+									ContainerConcurrency: ptr.Int64(1),
 									TimeoutSeconds:       ptr.Int64(99),
 								},
 							},
@@ -297,8 +301,8 @@ func TestServiceDefaulting(t *testing.T) {
 					Configuration: ConfigurationSpec{
 						DeprecatedRevisionTemplate: &RevisionTemplateSpec{
 							Spec: RevisionSpec{
-								RevisionSpec: v1beta1.RevisionSpec{
-									ContainerConcurrency: 1,
+								RevisionSpec: v1.RevisionSpec{
+									ContainerConcurrency: ptr.Int64(1),
 									TimeoutSeconds:       ptr.Int64(99),
 								},
 								DeprecatedContainer: &corev1.Container{
@@ -337,8 +341,9 @@ func TestServiceDefaulting(t *testing.T) {
 					Configuration: ConfigurationSpec{
 						DeprecatedRevisionTemplate: &RevisionTemplateSpec{
 							Spec: RevisionSpec{
-								RevisionSpec: v1beta1.RevisionSpec{
-									TimeoutSeconds: ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+								RevisionSpec: v1.RevisionSpec{
+									TimeoutSeconds:       ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+									ContainerConcurrency: ptr.Int64(config.DefaultContainerConcurrency),
 								},
 								DeprecatedContainer: &corev1.Container{
 									Name:           config.DefaultUserContainerName,
@@ -353,7 +358,7 @@ func TestServiceDefaulting(t *testing.T) {
 		},
 	}, {
 		name: "release (double, lemonade)",
-		wc:   v1beta1.WithUpgradeViaDefaulting,
+		wc:   v1.WithUpgradeViaDefaulting,
 		in: &Service{
 			Spec: ServiceSpec{
 				DeprecatedRelease: &ReleaseType{
@@ -374,8 +379,9 @@ func TestServiceDefaulting(t *testing.T) {
 				ConfigurationSpec: ConfigurationSpec{
 					Template: &RevisionTemplateSpec{
 						Spec: RevisionSpec{
-							RevisionSpec: v1beta1.RevisionSpec{
-								TimeoutSeconds: ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+							RevisionSpec: v1.RevisionSpec{
+								TimeoutSeconds:       ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+								ContainerConcurrency: ptr.Int64(config.DefaultContainerConcurrency),
 								PodSpec: corev1.PodSpec{
 									Containers: []corev1.Container{{
 										Name:           config.DefaultUserContainerName,
@@ -389,23 +395,23 @@ func TestServiceDefaulting(t *testing.T) {
 				},
 				RouteSpec: RouteSpec{
 					Traffic: []TrafficTarget{{
-						TrafficTarget: v1beta1.TrafficTarget{
+						TrafficTarget: v1.TrafficTarget{
 							Tag:            "current",
-							Percent:        57,
+							Percent:        ptr.Int64(57),
 							RevisionName:   "foo",
 							LatestRevision: ptr.Bool(false),
 						},
 					}, {
-						TrafficTarget: v1beta1.TrafficTarget{
+						TrafficTarget: v1.TrafficTarget{
 							Tag:            "candidate",
-							Percent:        43,
+							Percent:        ptr.Int64(43),
 							RevisionName:   "bar",
 							LatestRevision: ptr.Bool(false),
 						},
 					}, {
-						TrafficTarget: v1beta1.TrafficTarget{
+						TrafficTarget: v1.TrafficTarget{
 							Tag:            "latest",
-							Percent:        0,
+							Percent:        nil,
 							LatestRevision: ptr.Bool(true),
 						},
 					}},
@@ -414,7 +420,7 @@ func TestServiceDefaulting(t *testing.T) {
 		},
 	}, {
 		name: "release (double, @latest, lemonade)",
-		wc:   v1beta1.WithUpgradeViaDefaulting,
+		wc:   v1.WithUpgradeViaDefaulting,
 		in: &Service{
 			Spec: ServiceSpec{
 				DeprecatedRelease: &ReleaseType{
@@ -435,8 +441,9 @@ func TestServiceDefaulting(t *testing.T) {
 				ConfigurationSpec: ConfigurationSpec{
 					Template: &RevisionTemplateSpec{
 						Spec: RevisionSpec{
-							RevisionSpec: v1beta1.RevisionSpec{
-								TimeoutSeconds: ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+							RevisionSpec: v1.RevisionSpec{
+								TimeoutSeconds:       ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+								ContainerConcurrency: ptr.Int64(config.DefaultContainerConcurrency),
 								PodSpec: corev1.PodSpec{
 									Containers: []corev1.Container{{
 										Name:           config.DefaultUserContainerName,
@@ -450,22 +457,22 @@ func TestServiceDefaulting(t *testing.T) {
 				},
 				RouteSpec: RouteSpec{
 					Traffic: []TrafficTarget{{
-						TrafficTarget: v1beta1.TrafficTarget{
+						TrafficTarget: v1.TrafficTarget{
 							Tag:            "current",
-							Percent:        57,
+							Percent:        ptr.Int64(57),
 							RevisionName:   "foo",
 							LatestRevision: ptr.Bool(false),
 						},
 					}, {
-						TrafficTarget: v1beta1.TrafficTarget{
+						TrafficTarget: v1.TrafficTarget{
 							Tag:            "candidate",
-							Percent:        43,
+							Percent:        ptr.Int64(43),
 							LatestRevision: ptr.Bool(true),
 						},
 					}, {
-						TrafficTarget: v1beta1.TrafficTarget{
+						TrafficTarget: v1.TrafficTarget{
 							Tag:            "latest",
-							Percent:        0,
+							Percent:        nil,
 							LatestRevision: ptr.Bool(true),
 						},
 					}},
@@ -474,7 +481,7 @@ func TestServiceDefaulting(t *testing.T) {
 		},
 	}, {
 		name: "release (single, lemonade)",
-		wc:   v1beta1.WithUpgradeViaDefaulting,
+		wc:   v1.WithUpgradeViaDefaulting,
 		in: &Service{
 			Spec: ServiceSpec{
 				DeprecatedRelease: &ReleaseType{
@@ -494,8 +501,9 @@ func TestServiceDefaulting(t *testing.T) {
 				ConfigurationSpec: ConfigurationSpec{
 					Template: &RevisionTemplateSpec{
 						Spec: RevisionSpec{
-							RevisionSpec: v1beta1.RevisionSpec{
-								TimeoutSeconds: ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+							RevisionSpec: v1.RevisionSpec{
+								TimeoutSeconds:       ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+								ContainerConcurrency: ptr.Int64(config.DefaultContainerConcurrency),
 								PodSpec: corev1.PodSpec{
 									Containers: []corev1.Container{{
 										Name:           config.DefaultUserContainerName,
@@ -509,16 +517,16 @@ func TestServiceDefaulting(t *testing.T) {
 				},
 				RouteSpec: RouteSpec{
 					Traffic: []TrafficTarget{{
-						TrafficTarget: v1beta1.TrafficTarget{
+						TrafficTarget: v1.TrafficTarget{
 							Tag:            "current",
-							Percent:        100,
+							Percent:        ptr.Int64(100),
 							RevisionName:   "foo",
 							LatestRevision: ptr.Bool(false),
 						},
 					}, {
-						TrafficTarget: v1beta1.TrafficTarget{
+						TrafficTarget: v1.TrafficTarget{
 							Tag:            "latest",
-							Percent:        0,
+							Percent:        nil,
 							LatestRevision: ptr.Bool(true),
 						},
 					}},
@@ -534,8 +542,8 @@ func TestServiceDefaulting(t *testing.T) {
 						DeprecatedRevisionTemplate: &RevisionTemplateSpec{
 							Spec: RevisionSpec{
 								DeprecatedContainer: &corev1.Container{},
-								RevisionSpec: v1beta1.RevisionSpec{
-									ContainerConcurrency: 1,
+								RevisionSpec: v1.RevisionSpec{
+									ContainerConcurrency: ptr.Int64(1),
 									TimeoutSeconds:       ptr.Int64(99),
 								},
 							},
@@ -550,8 +558,8 @@ func TestServiceDefaulting(t *testing.T) {
 					Configuration: ConfigurationSpec{
 						DeprecatedRevisionTemplate: &RevisionTemplateSpec{
 							Spec: RevisionSpec{
-								RevisionSpec: v1beta1.RevisionSpec{
-									ContainerConcurrency: 1,
+								RevisionSpec: v1.RevisionSpec{
+									ContainerConcurrency: ptr.Int64(1),
 									TimeoutSeconds:       ptr.Int64(99),
 								},
 								DeprecatedContainer: &corev1.Container{
@@ -572,7 +580,7 @@ func TestServiceDefaulting(t *testing.T) {
 				ConfigurationSpec: ConfigurationSpec{
 					DeprecatedRevisionTemplate: &RevisionTemplateSpec{
 						Spec: RevisionSpec{
-							RevisionSpec: v1beta1.RevisionSpec{
+							RevisionSpec: v1.RevisionSpec{
 								PodSpec: corev1.PodSpec{
 									Containers: []corev1.Container{{
 										Image: "blah",
@@ -590,8 +598,9 @@ func TestServiceDefaulting(t *testing.T) {
 				ConfigurationSpec: ConfigurationSpec{
 					DeprecatedRevisionTemplate: &RevisionTemplateSpec{
 						Spec: RevisionSpec{
-							RevisionSpec: v1beta1.RevisionSpec{
-								TimeoutSeconds: ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+							RevisionSpec: v1.RevisionSpec{
+								TimeoutSeconds:       ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+								ContainerConcurrency: ptr.Int64(config.DefaultContainerConcurrency),
 								PodSpec: corev1.PodSpec{
 									Containers: []corev1.Container{{
 										Name:           config.DefaultUserContainerName,
@@ -606,9 +615,9 @@ func TestServiceDefaulting(t *testing.T) {
 				},
 				RouteSpec: RouteSpec{
 					Traffic: []TrafficTarget{{
-						TrafficTarget: v1beta1.TrafficTarget{
+						TrafficTarget: v1.TrafficTarget{
 							LatestRevision: ptr.Bool(true),
-							Percent:        100,
+							Percent:        ptr.Int64(100),
 						},
 					}},
 				},
@@ -629,8 +638,9 @@ func TestServiceDefaulting(t *testing.T) {
 				ConfigurationSpec: ConfigurationSpec{
 					DeprecatedRevisionTemplate: &RevisionTemplateSpec{
 						Spec: RevisionSpec{
-							RevisionSpec: v1beta1.RevisionSpec{
-								TimeoutSeconds: ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+							RevisionSpec: v1.RevisionSpec{
+								TimeoutSeconds:       ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+								ContainerConcurrency: ptr.Int64(config.DefaultContainerConcurrency),
 							},
 							DeprecatedContainer: &corev1.Container{
 								Name:           config.DefaultUserContainerName,
@@ -642,9 +652,9 @@ func TestServiceDefaulting(t *testing.T) {
 				},
 				RouteSpec: RouteSpec{
 					Traffic: []TrafficTarget{{
-						TrafficTarget: v1beta1.TrafficTarget{
+						TrafficTarget: v1.TrafficTarget{
 							LatestRevision: ptr.Bool(true),
-							Percent:        100,
+							Percent:        ptr.Int64(100),
 						},
 					}},
 				},
@@ -657,7 +667,7 @@ func TestServiceDefaulting(t *testing.T) {
 				ConfigurationSpec: ConfigurationSpec{
 					DeprecatedRevisionTemplate: &RevisionTemplateSpec{
 						Spec: RevisionSpec{
-							RevisionSpec: v1beta1.RevisionSpec{
+							RevisionSpec: v1.RevisionSpec{
 								PodSpec: corev1.PodSpec{
 									Containers: []corev1.Container{{
 										Image: "blah",
@@ -678,8 +688,9 @@ func TestServiceDefaulting(t *testing.T) {
 				ConfigurationSpec: ConfigurationSpec{
 					DeprecatedRevisionTemplate: &RevisionTemplateSpec{
 						Spec: RevisionSpec{
-							RevisionSpec: v1beta1.RevisionSpec{
-								TimeoutSeconds: ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+							RevisionSpec: v1.RevisionSpec{
+								TimeoutSeconds:       ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+								ContainerConcurrency: ptr.Int64(config.DefaultContainerConcurrency),
 								PodSpec: corev1.PodSpec{
 									Containers: []corev1.Container{{
 										Name:           config.DefaultUserContainerName,
@@ -694,9 +705,9 @@ func TestServiceDefaulting(t *testing.T) {
 				},
 				RouteSpec: RouteSpec{
 					Traffic: []TrafficTarget{{
-						TrafficTarget: v1beta1.TrafficTarget{
+						TrafficTarget: v1.TrafficTarget{
 							LatestRevision: ptr.Bool(true),
-							Percent:        100,
+							Percent:        ptr.Int64(100),
 						},
 					}},
 				},
@@ -709,7 +720,7 @@ func TestServiceDefaulting(t *testing.T) {
 				ConfigurationSpec: ConfigurationSpec{
 					DeprecatedRevisionTemplate: &RevisionTemplateSpec{
 						Spec: RevisionSpec{
-							RevisionSpec: v1beta1.RevisionSpec{
+							RevisionSpec: v1.RevisionSpec{
 								PodSpec: corev1.PodSpec{
 									Containers: []corev1.Container{{
 										Image: "blah",
@@ -721,8 +732,8 @@ func TestServiceDefaulting(t *testing.T) {
 				},
 				RouteSpec: RouteSpec{
 					Traffic: []TrafficTarget{{
-						TrafficTarget: v1beta1.TrafficTarget{
-							Percent: 100,
+						TrafficTarget: v1.TrafficTarget{
+							Percent: ptr.Int64(100),
 						},
 					}},
 				},
@@ -733,8 +744,9 @@ func TestServiceDefaulting(t *testing.T) {
 				ConfigurationSpec: ConfigurationSpec{
 					DeprecatedRevisionTemplate: &RevisionTemplateSpec{
 						Spec: RevisionSpec{
-							RevisionSpec: v1beta1.RevisionSpec{
-								TimeoutSeconds: ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+							RevisionSpec: v1.RevisionSpec{
+								TimeoutSeconds:       ptr.Int64(config.DefaultRevisionTimeoutSeconds),
+								ContainerConcurrency: ptr.Int64(config.DefaultContainerConcurrency),
 								PodSpec: corev1.PodSpec{
 									Containers: []corev1.Container{{
 										Name:           config.DefaultUserContainerName,
@@ -749,9 +761,9 @@ func TestServiceDefaulting(t *testing.T) {
 				},
 				RouteSpec: RouteSpec{
 					Traffic: []TrafficTarget{{
-						TrafficTarget: v1beta1.TrafficTarget{
+						TrafficTarget: v1.TrafficTarget{
 							LatestRevision: ptr.Bool(true),
-							Percent:        100,
+							Percent:        ptr.Int64(100),
 						},
 					}},
 				},
