@@ -30,6 +30,8 @@ import (
 const (
 	// ConfigName is the name of the config map of the autoscaler.
 	ConfigName = "config-autoscaler"
+
+	defaultTargetUtilization = 0.7
 )
 
 // Config defines the tunable autoscaler parameters
@@ -41,11 +43,20 @@ type Config struct {
 	// Target concurrency knobs for different container concurrency configurations.
 	ContainerConcurrencyTargetFraction float64
 	ContainerConcurrencyTargetDefault  float64
+	// TargetUtilization is used for the metrics other than concurrency. This is not
+	// configurable now. Customers can override it by specifying
+	// autoscaling.knative.dev/targetUtilizationPercentage in Revision annotation.
+	// TODO(yanweiguo): Expose this to config-autoscaler configmap and eventually
+	// deprecate ContainerConcurrencyTargetFraction.
+	TargetUtilization float64
+	// RPSTargetDefault is the default target value for requests per second.
+	RPSTargetDefault float64
 	// NB: most of our computations are in floats, so this is float to avoid casting.
 	TargetBurstCapacity float64
 
 	// General autoscaler algorithm configuration.
 	MaxScaleUpRate           float64
+	MaxScaleDownRate         float64
 	StableWindow             time.Duration
 	PanicWindowPercentage    float64
 	PanicThresholdPercentage float64
@@ -58,7 +69,9 @@ type Config struct {
 
 // NewConfigFromMap creates a Config from the supplied map
 func NewConfigFromMap(data map[string]string) (*Config, error) {
-	lc := &Config{}
+	lc := &Config{
+		TargetUtilization: defaultTargetUtilization,
+	}
 
 	// Process bool fields.
 	for _, b := range []struct {
@@ -87,19 +100,27 @@ func NewConfigFromMap(data map[string]string) (*Config, error) {
 		key:          "max-scale-up-rate",
 		field:        &lc.MaxScaleUpRate,
 		defaultValue: 1000.0,
+	}, {
+		key:          "max-scale-down-rate",
+		field:        &lc.MaxScaleDownRate,
+		defaultValue: 2.0,
 	}, {
 		key:   "container-concurrency-target-percentage",
 		field: &lc.ContainerConcurrencyTargetFraction,
 		// TODO(#1956): Tune target usage based on empirical data.
-		defaultValue: 0.7,
+		defaultValue: defaultTargetUtilization,
 	}, {
 		key:          "container-concurrency-target-default",
 		field:        &lc.ContainerConcurrencyTargetDefault,
 		defaultValue: 100.0,
+	}, {
+		key:          "requests-per-second-target-default",
+		field:        &lc.RPSTargetDefault,
+		defaultValue: 200.0,
 	}, {
 		key:          "target-burst-capacity",
 		field:        &lc.TargetBurstCapacity,
-		defaultValue: 0,
+		defaultValue: 200,
 	}, {
 		key:          "panic-window-percentage",
 		field:        &lc.PanicWindowPercentage,
@@ -172,10 +193,22 @@ func validate(lc *Config) (*Config, error) {
 		return nil, fmt.Errorf("container-concurrency-target-percentage = %f is outside of valid range of (0, 100]", lc.ContainerConcurrencyTargetFraction)
 	}
 
-	if x := lc.ContainerConcurrencyTargetFraction * lc.ContainerConcurrencyTargetDefault; x < 1.0 {
+	if x := lc.ContainerConcurrencyTargetFraction * lc.ContainerConcurrencyTargetDefault; x < autoscaling.TargetMin {
 		return nil, fmt.Errorf("container-concurrency-target-percentage and container-concurrency-target-default yield target concurrency of %f, can't be less than 1", x)
 	}
 
+	if lc.RPSTargetDefault < autoscaling.TargetMin {
+		return nil, fmt.Errorf("requests-per-second-target-default must be at least %v, got %v", autoscaling.TargetMin, lc.RPSTargetDefault)
+	}
+
+	if lc.MaxScaleUpRate <= 1.0 {
+		return nil, fmt.Errorf("max-scale-up-rate = %v, must be greater than 1.0", lc.MaxScaleUpRate)
+	}
+
+	if lc.MaxScaleDownRate <= 1.0 {
+		return nil, fmt.Errorf("max-scale-down-rate = %v, must be greater than 1.0", lc.MaxScaleDownRate)
+	}
+
 	// We can't permit stable window be less than our aggregation window for correctness.
 	if lc.StableWindow < autoscaling.WindowMin {
 		return nil, fmt.Errorf("stable-window = %v, must be at least %v", lc.StableWindow, BucketSize)
